OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contactpersonen",
    "Copy Url to clipboard" : "Kopiëren URL naar klembord",
    "Download" : "Downloaden",
    "ShowURL" : "ShowURL",
    "Share Addressbook" : "Delen adresboek",
    "Delete Addressbook" : "Verwijder adresboek",
    "Share with users or groups" : "Delen met gebruikers of groepen",
    "Delete" : "Verwijderen",
    "can edit" : "kan wijzigen",
    "Address book name" : "Adresboek naam",
    "Import" : "Importeer",
    "The selected image is too big (max 1MB)" : "De geselecteerde afbeelding is te groot (max 1MB)",
    "No contacts in here" : "Hier geen contactpersonen gevonden",
    "Name" : "Naam",
    "Organization" : "Organisatie",
    "Title" : "Titel",
    "Add field ..." : "Voeg veld toe",
    "No search result for {query}" : "Geen zoekresultaten voor {query}",
    "_%n contact_::_%n contacts_" : ["%n contactpersoon","%n contactpersonen"],
    "Post office box" : "Postbus",
    "Postal code" : "Postcode",
    "City" : "Stad",
    "State or province" : "Staat of provincie",
    "Country" : "Land",
    "Address" : "Adres",
    "(new group)" : "(nieuwe groep)",
    "Last name" : "Achternaam",
    "First name" : "Voornaam",
    "Additional names" : "Extra namen",
    "Prefix" : "Voorvoegsel",
    "Suffix" : "Achtervoegsel",
    "All contacts" : "Alle contactpersonen",
    "Not grouped" : "Niet gegroepeerd",
    "New contact" : "Nieuwe contactpersoon",
    "{addressbook} shared by {owner}" : "{addressbook} gedeeld door {owner}",
    "Contact could not be created." : "Contact kon niet worden aangemaakt.",
    "No contacts in file. Only VCard files are allowed." : "Geen contacten in bestand. Alleen VCard bestanden zijn toegestaan.",
    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Alleen VCard versie 4.0 (RFC6350) of versie 3.0 (RFC2426) worden ondersteund.",
    "Nickname" : "Roepnaam",
    "Detailed name" : "Gedetailleerde naam",
    "Notes" : "Notities",
    "Website" : "Website",
    "Federated Cloud ID" : "Gefedereerde Cloud ID",
    "Home" : "Thuis",
    "Work" : "Werk",
    "Other" : "Overig",
    "Groups" : "Groepen",
    "Birthday" : "Verjaardag",
    "Anniversary" : "Verjaardag",
    "Date of death" : "Overlijdensdatum",
    "Email" : "mailadres",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Telefoon",
    "Mobile" : "Mobiel",
    "Fax" : "Fax",
    "Fax home" : "Fax thuis",
    "Fax work" : "Fax werk",
    "Pager" : "Pieper",
    "Voice" : "Stem",
    "Social network" : "Social network",
    "Settings" : "Instellingen"
},
"nplurals=2; plural=(n != 1);");
